SequentialConfig

Struct SequentialConfig 

pub struct SequentialConfig {
    pub committer: CommitterConfig,
    pub ingestion: IngestionConfig,
    pub fanout: Option<ConcurrencyConfig>,
    pub min_eager_rows: Option<usize>,
    pub max_pending_rows: Option<usize>,
    pub max_batch_checkpoints: Option<usize>,
    pub processor_channel_size: Option<usize>,
    pub pipeline_depth: Option<usize>,
}
Configuration for a sequential pipeline

Fields

committer: CommitterConfig

Configuration for the writer, that makes forward progress.

ingestion: IngestionConfig

Per-pipeline ingestion overrides.

fanout: Option<ConcurrencyConfig>

Processor concurrency. Defaults to adaptive scaling up to the number of CPUs.

min_eager_rows: Option<usize>

Override for Handler::MIN_EAGER_ROWS (eager batch threshold).

max_pending_rows: Option<usize>

Override for Handler::MAX_PENDING_ROWS (soft cap).

max_batch_checkpoints: Option<usize>

Override for Handler::MAX_BATCH_CHECKPOINTS (checkpoints per write batch).

processor_channel_size: Option<usize>

Size of the channel between the processor and committer.

pipeline_depth: Option<usize>

Depth of the channel between the collector and committer tasks. Allows the collector to build the next batch while the previous batch is being flushed to the DB.